@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.113';
+our $VERSION = '0.114';
 
 use feature 'switch';
 
@@ -46,7 +46,7 @@ use Text::Balanced qw(extract_quotelike);
 use Text::Wrap qw(fill);
 use User::pwent;
 
-use constant debstdversion => '4.5.0';
+use constant debstdversion => '4.5.1';
 
 our %DEFAULTS = (
 );
@@ -1624,48 +1624,72 @@ sub create_upstream_metadata {
     $upstream{"Repository"}        = $meta->{resources}->{repository}->{url};
     $upstream{"Repository-Browse"} = $meta->{resources}->{repository}->{web};
 
-    if (defined $upstream{"Repository"}) {
-        my $fix_browse = ! defined $upstream{"Repository-Browse"};
+    # we don't care to write debian/upstream/metadata
+    # if we don't have a Repository
+    return unless defined $upstream{"Repository"};
 
-        my $url_parser = qr|(?:([^:/?\#]+):)? # protocol
-                            (?://([^/?\#]*))? # domain name
-                            ([^?\#]*)         # path
-                            (?:\?([^\#]*))?   # query
-                            (?:\#(.*))?       # fragment
-                           |x;
+    my $fix_browse = ! defined $upstream{"Repository-Browse"};
 
-        my ($protocol, $domain, $path, $query, $fragment)
-            = $upstream{"Repository"} =~ $url_parser;
+    my $url_parser = qr|(?:([^:/?\#]+):)? # protocol
+                        (?://([^/?\#]*))? # domain name
+                        ([^?\#]*)         # path
+                        (?:\?([^\#]*))?   # query
+                        (?:\#(.*))?       # fragment
+                       |x;
 
-        # fixups:
-        # strip user@, e.g. 'ssh://git@github.com/user/project.git'
-        $domain =~ s|^[^@]+@||;
-        # handle : after host, e.g.'git://git@github.com:user/project.git'
-        if ( $domain =~ m/:/ ) {
-            my ( $domainpart, $userpart ) = split /:/, $domain;
-            $domain = $domainpart;
-            $path   = '/' . $userpart . $path;
+    my ($protocol, $domain, $path, $query, $fragment)
+        = $upstream{"Repository"} =~ $url_parser;
+
+    # fixups:
+    # strip user@, e.g. 'ssh://git@github.com/user/project.git'
+    $domain =~ s|^[^@]+@||;
+    # handle : after host, e.g.'git://git@github.com:user/project.git'
+    if ( $domain =~ m/:/ ) {
+        my ( $domainpart, $userpart ) = split /:/, $domain;
+        $domain = $domainpart;
+        $path   = '/' . $userpart . $path;
+    }
+
+    my $host = {
+        'github.com'    => 'github',
+        'gitlab.com'    => 'gitlab',
+        'bitbucket.org' => 'bitbucket',
+    }->{$domain};
+
+    if (defined $host) {
+        if ($protocol ne "https") {
+            $upstream{"Repository"} = "https://$domain$path";
         }
-
-        my $host = {
-            'github.com'    => 'github',
-            'gitlab.com'    => 'gitlab',
-            'bitbucket.org' => 'bitbucket',
-        }->{$domain};
-
-        if (defined $host) {
-            if ($protocol ne "https") {
-                $upstream{"Repository"} = "https://$domain$path";
-            }
-            if ($fix_browse) {
-                $path =~ s/\.git$//;
-                $upstream{"Repository-Browse"} = "https://$domain$path";
-            }
+        if ($fix_browse) {
+            $path =~ s/\.git$//;
+            $upstream{"Repository-Browse"} = "https://$domain$path";
         }
-    } else {
-        # we don't care to write debian/upstream/metadata
-        # if we don't have a Repository
-        return;
+        # fix remaining non-HTTPS URLs
+        foreach ( qw(
+            Bug-Database
+            Bug-Submit
+            Repository
+            Repository-Browse
+        )) {
+            $upstream{$_} =~ s|^http://|https://| if $upstream{$_};
+        }
+    }
+
+    # GitHub fixups
+    # TODO: this is copied from dpt-debian-upstream
+    if (   defined $upstream{"Bug-Database"}
+        && $upstream{"Bug-Database"} =~ /github\.com.+issues\/?$/
+        && !$upstream{"Bug-Submit"} )
+    {
+        $upstream{"Bug-Database"} =~ s/\/$//;
+        $upstream{"Bug-Submit"} = $upstream{"Bug-Database"} . '/new';
+    }
+    if (   defined $upstream{"Repository"}
+        && $upstream{"Repository"} =~ /github\.com/
+        && $upstream{"Repository"} !~ /\.git$/ )
+    {
+        $upstream{"Repository"} =~ s/\/$//;
+        $upstream{"Repository"} .= '.git';
     }
 
     foreach ( keys %upstream ) {
@@ -1748,7 +1772,7 @@ sub _file_w {
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2020 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2021, gregor herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007-2013 Damyan Ivanov <dmn@debian.org>
 
